@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA 02110-1301  USA
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1335 USA
  */
 
 #include <config.h>
@@ -441,7 +441,7 @@ help_about (GSimpleAction *action,
        "the GNU General Public License and Unicode Copyright for more details."),
     N_("You should have received a copy of the GNU General Public License "
        "along with Gucharmap; if not, write to the Free Software Foundation, Inc., "
-       "59 Temple Place, Suite 330, Boston, MA  02110-1301  USA"),
+       "51 Franklin Street, Fifth Floor, Boston, MA 02110-1335 USA"),
     N_("Also you should have received a copy of the Unicode Copyright along "
        "with Gucharmap; you can always find it at Unicode's website: "
        "http://www.unicode.org/copyright.html")
@@ -454,10 +454,10 @@ help_about (GSimpleAction *action,
   gtk_show_about_dialog (GTK_WINDOW (guw),
 			 "program-name", _("GNOME Character Map"),
 			 "version", VERSION,
-			 "comments", _("Based on the Unicode Character Database 9.0.0"),
+			 "comments", _("Based on the Unicode Character Database 10.0.0"),
 			 "copyright", "Copyright © 2004 Noah Levitt\n"
-				      "Copyright © 1991–2016 Unicode, Inc.\n"
-				      "Copyright © 2007–2016 Christian Persch\n"
+				      "Copyright © 1991–2017 Unicode, Inc.\n"
+				      "Copyright © 2007–2017 Christian Persch\n"
                                       "Copyright © 2016 DaeHyun Sung",
 			 "documenters", documenters,
 			 "license", license_trans,
